%Calculo de voltajes y corrientes de un circuito no plano
% según el análisis de malla por inspección direccional
% Nombre del script: pentagrama.m
% Fecha: 05.06.2022
clc;
clear;
%Resistencias de rama (Fig. 3)
Ra=1; %Resistencia en 𝛀
Rb=2; %Resistencia en 𝛀
Rc=3; %Resistencia en 𝛀
Re=4; %Resistencia en 𝛀
Rd=5; %Resistencia en 𝛀
Rf=6; %Resistencia en 𝛀
Rg=7; %Resistencia en 𝛀
Rh=8; %Resistencia en 𝛀
Rj=9; %Resistencia en 𝛀
Ri=10; %Resistencia en 𝛀
% Matriz de resistencias RM (Ecuacion 4)
RM=[ (Rd+Re+Ra) Ra Ra Re 0 Re;
 Ra (Rf+Rc+Ra) Ra 0 Rc -Rc;
 Ra Ra (Rg+Rb+Ra) -Rb -Rb 0;
 Re 0 -Rb (Rh+Rb+Re) Rb Re;
 0 Rc -Rb Rb (Rj+Rc+Rb) -Rc ;
 Re -Rc 0 Re -Rc (Ri+Re+Rc)]
%Fuentes de voltaje y corriente en las ramas (Fig. 3)
VSA=5; % Voltaje en V
VSB=7; %Voltaje en V
% Vector de las fuentes de Voltaje VM (Ecuacion 5)
VM=[0;VSA;0;-VSB;0;0]
%Calculo de las corrientes de malla IM (Ecuacion 6)
IM= (RM^(-1)) *VM
%Calculo de las corrientes de rama Ira (Ecuacion 7)
Id=IM(1); % IM(1) corresponde a IMI (Tabla 1)
I_f=IM(2); % IM(2) corresponde a IMII (Tabla 1)
Ig=IM(3); % IM(3) corresponde a IMIII (Tabla 1)
Ih=IM(4); % IM(4) corresponde a IMIV (Tabla 1)
Ij=IM(5); % IM(5) corresponde a IMV (Tabla 1)
Ii=IM(6); % IM(6) corresponde a IMVI (Tabla 1)
Ia=(IM(1)+IM(2)+IM(3)); % (Ecuacion 7)
Ib=-IM(3)+IM(4)+IM(5); % (Ecuacion 7)
Ic=-IM(2)-IM(5)+IM(6); % (Ecuacion 7)
Ie=-(IM(1)+IM(4)+IM(6)); % (Ecuacion 7)
%Calculo de los voltajes de rama Vra (Ecuacion 8)
Va=Ra*Ia; %(Ecuacion 8)
Vb=Rb*Ib; %(Ecuacion 8)
Vc=Rc*Ic; %(Ecuacion 8)
Vd=Rd*Id; %(Ecuacion 8)
Ve=Re*Ie; %(Ecuacion 8)
Vf=Rf*I_f-VSA; %(Ecuacion 8 y 9)
Vg=Rg*Ig; %(Ecuacion 8)
Vh=Rh*Ih+VSB; %(Ecuacion 8 y 9)
Vi=Ri*Ii; %(Ecuacion 8)
Vj=Rj*Ij; %(Ecuacion 8)
%Vector de corriente de rama IraM (Orden segun ecuacion 1)
IraM=[Ia;Ib;Ic;Ie;Id;I_f;Ig;Ih;Ij;Ii]
%Vector de voltajes de rama (Orden segun ecuacion 1)
VraM=[Va;Vb;Vc;Ve;Vd;Vf;Vg;Vh;Vj;Vi]
%Balance de potencia según teorema de Weyl y Tellegen
PraM=VraM'*IraM % (Ecuacion 9)
% Análisis nodal
% Calculo de las conductividades
Ga=1/Ra;
Gb=1/Rb;
Gc=1/Rc;
Gd=1/Rd;
Ge=1/Re;
Gf=1/Rf;
Gg=1/Rg;
Gh=1/Rh;
Gi=1/Ri;
Gj=1/Rj;
% Conversión de fuentes de voltaje en fuentes de corriente segun
% Mayer y Norton (Fig. 5)
ISA=VSA/Rf %(Figura 5)
ISB=VSB/Rh %(Figura 5)
% Vector de las fuentes de corriente (Ecuacion 14)
IN=[ISA;-ISB;-ISA;ISB]
% Matriz de las conductividades GN (Ecuacion 13)
GN=[(Ga+Gf+Gd+Gg) (-Gg) (-Gf) (-Gd);
 (-Gg) (Gb+Gj+Gh+Gg) (-Gj) (-Gh);
 (-Gf) (-Gj) (Gj+Gf+Gc+Gi) (-Gi);
 (-Gd) (-Gh) (-Gi) (Ge+Gh+Gd+Gi)]
%Calculo del vector de voltajes nodales (Ecuacion 15)
VN=GN^(-1)*IN
%Calculo de voltajes de ramas Vra (Ecuacion 16)
Va=VN(1); %(Ecuacion 16 con Vv=0V)
Vb=VN(2); %(Ecuacion 16 con Vv=0V)
Vc=VN(3); %(Ecuacion 16 con Vv=0V)
Ve=VN(4); %(Ecuacion 16 con Vv=0V)
Vd=VN(4)-VN(1); %(Ecuacion 16)
Vf=VN(3)-VN(1); %(Ecuacion 16)
Vg=VN(2)-VN(1); %(Ecuacion 16)
Vh=VN(4)-VN(2); %(Ecuacion 16)
Vj=VN(3)-VN(2); %(Ecuacion 16)
Vi=VN(4)-VN(3); %(Ecuacion 16)
%Vector de voltajes de rama (Orden segun ecuacion 1).
VraN=[Va;Vb;Vc;Ve;Vd;Vf;Vg;Vh;Vj;Vi]
%Calculo de las corrientes de rama Ira (Ecuaciones 17 y 18)
Ia=Ga*Va; %(Ecuacion 17)
Ib=Gb*Vb; %(Ecuacion 17)
Ic=Gc*Vc; %(Ecuacion 17)
Id=Gd*Vd; %(Ecuacion 17)
Ie=Ge*Ve; %(Ecuacion 17)
I_f=Gf*Vf+ISA;
Ig=Gg*Vg; %(Ecuacion 17 y18)
Ih=Gh*Vh-ISB;
Ij=Gj*Vj; %(Ecuacion 17 y18)
Ii=Gi*Vi; %(Ecuacion 17)
%Vector de corriente de rama (Orden segun ecuacion 1)
IraN=[Ia;Ib;Ic;Ie;Id;I_f;Ig;Ih;Ij;Ii]
%Balance de potencia segun teorema de Weyl y Tellegen
% (Ecuacion 19)
PraN=VraN'*IraN

